Index: src/Fl_Window.cxx
===================================================================
--- src/Fl_Window.cxx	(revision 6985)
+++ src/Fl_Window.cxx	(working copy)
@@ -52,6 +52,7 @@
   }
   i = 0;
   xclass_ = 0;
+  xtype_ = FL_NORMAL_WINDOW;
   icon_ = 0;
   iconlabel_ = 0;
   resizable(0);
Index: src/Fl_x.cxx
===================================================================
--- src/Fl_x.cxx	(revision 6985)
+++ src/Fl_x.cxx	(working copy)
@@ -1544,6 +1544,22 @@
                       (unsigned char *)buffer, p-buffer-1);
     }
 
+	// set the window type to normal
+	Atom net_wm_type = XInternAtom(fl_display, "_NET_WM_WINDOW_TYPE", False);
+	Atom net_wm_type_kind = 0;
+
+	switch(win->xtype())
+	{
+		case FL_DIALOG_WINDOW:
+			net_wm_type_kind = XInternAtom(fl_display, "_NET_WM_WINDOW_TYPE_DIALOG", False);
+			break;
+
+		case FL_NORMAL_WINDOW:
+		default:
+			net_wm_type_kind = XInternAtom(fl_display, "_NET_WM_WINDOW_TYPE_NORMAL", False);
+	}
+    XChangeProperty(fl_display, xp->xid, net_wm_type, XA_ATOM, 32, PropModeReplace, (unsigned char*) &net_wm_type_kind, 1);
+
     if (win->non_modal() && xp->next && !fl_disable_transient_for) {
       // find some other window to be "transient for":
       Fl_Window* wp = xp->next->w;
Index: FL/Enumerations.H
===================================================================
--- FL/Enumerations.H	(revision 6985)
+++ FL/Enumerations.H	(working copy)
@@ -597,6 +597,11 @@
   FL_FREE_LABELTYPE		///< first free labeltype to use for creating own labeltypes
 };
 
+enum Fl_Windowtype { // window type
+	FL_NORMAL_WINDOW = 0,	///< A normal window (default)
+	FL_DIALOG_WINDOW		///< A dialog window
+};
+
 /** 
   Sets the current  label type end return its corresponding Fl_Labeltype value. 
   @{
Index: FL/Fl_Window.H
===================================================================
--- FL/Fl_Window.H	(revision 6985)
+++ FL/Fl_Window.H	(working copy)
@@ -62,6 +62,7 @@
 
   const char* iconlabel_;
   const char* xclass_;
+  Fl_Windowtype xtype_;
   const void* icon_;
   // size_range stuff:
   int minw, minh, maxw, maxh;
@@ -340,6 +341,16 @@
     is not copied.
   */
   void xclass(const char* c)	{xclass_ = c;}
+  /** See void Fl_Window::xtype(Fl_Windowytype) */
+  Fl_Windowtype xtype() const {return xtype_;}
+  /**
+  	The classification to tell the system what type of window this is. Under X,
+	this is used by the window managers to apply consistent decoration,
+	stacking, etc. to all windows of the same type.
+	<P>By default, a Fl_Window is created as a <I>Normal</I> window. Use this to indicate
+	that this Fl_Window is of another kind (e.g. a dialog window).
+  */
+  void xtype(Fl_Windowtype t) {xtype_ = t;}
   /** Gets the current icon window target dependent data. */
   const void* icon() const	{return icon_;}
   /** Sets the current icon window target dependent data. */
Index: fluid/about_panel.fl
===================================================================
--- fluid/about_panel.fl	(revision 6985)
+++ fluid/about_panel.fl	(working copy)
@@ -34,11 +34,11 @@
 decl {void show_help(const char *name);} {public
 } 
 
-Function {make_about_panel()} {selected
-} {
+Function {make_about_panel()} {} {
   Fl_Window about_panel {
-    label {About FLUID} open
-    xywh {419 216 315 175} type Double color 50 selection_color 47 hotspot non_modal visible
+    label {About FLUID} open selected
+    xywh {173 306 315 175} type Double color 50 selection_color 47 hotspot
+    code0 {o->xtype(FL_DIALOG_WINDOW);} non_modal visible
   } {
     Fl_Box {} {
       image {icons/fluid-96.xpm} xywh {10 10 115 120}
Index: fluid/about_panel.cxx
===================================================================
--- fluid/about_panel.cxx	(revision 6985)
+++ fluid/about_panel.cxx	(working copy)
@@ -271,7 +271,7 @@
 }
 
 Fl_Double_Window* make_about_panel() {
-  { about_panel = new Fl_Double_Window(315, 175, "About FLUID");
+  { Fl_Double_Window* o = about_panel = new Fl_Double_Window(315, 175, "About FLUID");
     about_panel->color(FL_LIGHT1);
     about_panel->selection_color(FL_DARK1);
     about_panel->hotspot(about_panel);
@@ -283,10 +283,10 @@
       o->selection_color(FL_DARK1);
       o->labelfont(1);
       o->labelsize(18);
-      o->align(FL_ALIGN_TOP_LEFT|FL_ALIGN_INSIDE);
+      o->align(Fl_Align(FL_ALIGN_TOP_LEFT|FL_ALIGN_INSIDE));
     } // Fl_Box* o
     { Fl_Box* o = new Fl_Box(135, 89, 170, 42, "Copyright 1998-2009 by\nBill Spitzak and others");
-      o->align(132|FL_ALIGN_INSIDE);
+      o->align(Fl_Align(132|FL_ALIGN_INSIDE));
     } // Fl_Box* o
     { Fl_Button* o = new Fl_Button(89, 141, 123, 25, "View License...");
       o->labelcolor(FL_DARK_BLUE);
@@ -295,6 +295,7 @@
     { Fl_Return_Button* o = new Fl_Return_Button(222, 141, 83, 25, "Close");
       o->callback((Fl_Callback*)cb_Close);
     } // Fl_Return_Button* o
+    o->xtype(FL_DIALOG_WINDOW);
     about_panel->set_non_modal();
     about_panel->end();
   } // Fl_Double_Window* about_panel
Index: fluid/template_panel.cxx
===================================================================
--- fluid/template_panel.cxx	(revision 6985)
+++ fluid/template_panel.cxx	(working copy)
@@ -142,18 +142,18 @@
 }
 
 Fl_Double_Window* make_template_panel() {
-  { template_panel = new Fl_Double_Window(460, 355, "New/Save Template");
+  { Fl_Double_Window* o = template_panel = new Fl_Double_Window(460, 355, "New/Save Template");
     template_panel->callback((Fl_Callback*)cb_template_panel);
     { template_browser = new Fl_Browser(10, 28, 180, 250, "Available Templates:");
       template_browser->type(2);
       template_browser->labelfont(1);
       template_browser->callback((Fl_Callback*)cb_template_browser);
-      template_browser->align(FL_ALIGN_TOP_LEFT);
+      template_browser->align(Fl_Align(FL_ALIGN_TOP_LEFT));
       template_browser->when(3);
     } // Fl_Browser* template_browser
     { template_preview = new Fl_Box(200, 28, 250, 250);
       template_preview->box(FL_THIN_DOWN_BOX);
-      template_preview->align(69|FL_ALIGN_INSIDE);
+      template_preview->align(Fl_Align(69|FL_ALIGN_INSIDE));
       Fl_Group::current()->resizable(template_preview);
     } // Fl_Box* template_preview
     { template_name = new Fl_Input(124, 288, 326, 25, "Template Name:");
@@ -182,6 +182,7 @@
       } // Fl_Return_Button* template_submit
       o->end();
     } // Fl_Group* o
+    o->xtype(FL_DIALOG_WINDOW);
     template_panel->set_modal();
     template_panel->end();
   } // Fl_Double_Window* template_panel
Index: fluid/alignment_panel.fl
===================================================================
--- fluid/alignment_panel.fl	(revision 6985)
+++ fluid/alignment_panel.fl	(working copy)
@@ -46,13 +46,13 @@
 decl {extern int show_comments;} {public
 } 
 
-Function {make_project_window()} {selected
-} {
+Function {make_project_window()} {} {
   Fl_Window project_window {
     label {Project Settings}
-    xywh {312 395 358 207} type Double
+    xywh {52 415 355 205} type Double
     code0 {\#include <FL/Fl_Preferences.H>}
-    code1 {\#include <FL/Fl_Tooltip.H>} modal visible
+    code1 {\#include <FL/Fl_Tooltip.H>}
+    code2 {o->xtype(FL_DIALOG_WINDOW);} modal visible
   } {
     Fl_Button {} {
       label Close
@@ -156,7 +156,8 @@
 } {
   Fl_Window settings_window {
     label {GUI Settings} open
-    xywh {393 191 342 242} type Double non_modal visible
+    xywh {95 70 340 240} type Double
+    code0 {o->xtype(FL_DIALOG_WINDOW);} non_modal visible
   } {
     Fl_Choice scheme_choice {
       label {Scheme:}
@@ -241,7 +242,7 @@
       label {\# Recent Files:}
       callback {fluid_prefs.set("recent_files", recent_spinner->value());
 load_history();}
-      xywh {115 170 40 25} labelfont 1 when 1 value 1
+      xywh {115 170 40 25} labelfont 1 when 1
       code0 {int c;}
       code1 {fluid_prefs.get("recent_files", c, 5);}
       code2 {recent_spinner->maximum(10);}
@@ -324,8 +325,9 @@
 Function {make_layout_window()} {open
 } {
   Fl_Window grid_window {
-    label {Layout Settings} open
-    xywh {676 337 285 245} type Double non_modal visible
+    label {Layout Settings} open selected
+    xywh {481 651 285 245} type Double
+    code0 {o->xtype(FL_DIALOG_WINDOW);} non_modal visible
   } {
     Fl_Input horizontal_input {
       label x
Index: fluid/alignment_panel.cxx
===================================================================
--- fluid/alignment_panel.cxx	(revision 6985)
+++ fluid/alignment_panel.cxx	(working copy)
@@ -61,7 +61,7 @@
 Fl_Input *i18n_function_input=(Fl_Input *)0;
 
 Fl_Double_Window* make_project_window() {
-  { project_window = new Fl_Double_Window(358, 207, "Project Settings");
+  { Fl_Double_Window* o = project_window = new Fl_Double_Window(355, 205, "Project Settings");
     { Fl_Button* o = new Fl_Button(293, 175, 52, 20, "Close");
       o->tooltip("Close this dialog.");
       o->labelsize(11);
@@ -164,6 +164,7 @@
       } // Fl_Group* o
       o->end();
     } // Fl_Tabs* o
+    o->xtype(FL_DIALOG_WINDOW);
     project_window->set_modal();
     project_window->end();
   } // Fl_Double_Window* project_window
@@ -229,7 +230,7 @@
 }
 
 Fl_Double_Window* make_settings_window() {
-  { settings_window = new Fl_Double_Window(342, 242, "GUI Settings");
+  { Fl_Double_Window* o = settings_window = new Fl_Double_Window(340, 240, "GUI Settings");
     { scheme_choice = new Fl_Choice(116, 10, 115, 25, "Scheme:");
       scheme_choice->down_box(FL_BORDER_BOX);
       scheme_choice->labelfont(1);
@@ -282,7 +283,6 @@
     } // Fl_Group* o
     { recent_spinner = new Fl_Spinner(115, 170, 40, 25, "# Recent Files:");
       recent_spinner->labelfont(1);
-      recent_spinner->value(1);
       recent_spinner->callback((Fl_Callback*)cb_recent_spinner);
       recent_spinner->when(FL_WHEN_CHANGED);
       int c;
@@ -294,6 +294,7 @@
       o->tooltip("Close this dialog.");
       o->callback((Fl_Callback*)cb_Close1);
     } // Fl_Button* o
+    o->xtype(FL_DIALOG_WINDOW);
     settings_window->set_non_modal();
     settings_window->end();
   } // Fl_Double_Window* settings_window
@@ -412,7 +413,7 @@
 Fl_Round_Button *def_widget_size[6]={(Fl_Round_Button *)0};
 
 Fl_Double_Window* make_layout_window() {
-  { grid_window = new Fl_Double_Window(285, 245, "Layout Settings");
+  { Fl_Double_Window* o = grid_window = new Fl_Double_Window(285, 245, "Layout Settings");
     { Fl_Input* o = horizontal_input = new Fl_Input(106, 10, 50, 25, "x");
       horizontal_input->tooltip("Horizontal grid spacing.");
       horizontal_input->type(2);
@@ -510,6 +511,7 @@
       } // Fl_Box* o
       o->end();
     } // Fl_Group* o
+    o->xtype(FL_DIALOG_WINDOW);
     grid_window->set_non_modal();
     grid_window->end();
   } // Fl_Double_Window* grid_window
Index: fluid/widget_panel.cxx
===================================================================
--- fluid/widget_panel.cxx	(revision 6985)
+++ fluid/widget_panel.cxx	(working copy)
@@ -63,7 +63,7 @@
   { Fl_Double_Window* o = new Fl_Double_Window(420, 360);
     w = o;
     o->labelsize(11);
-    o->align(FL_ALIGN_CLIP|FL_ALIGN_INSIDE);
+    o->align(Fl_Align(FL_ALIGN_CLIP|FL_ALIGN_INSIDE));
     o->hotspot(o);
     { Fl_Tabs* o = new Fl_Tabs(10, 10, 400, 310);
       o->selection_color((Fl_Color)12);
@@ -80,7 +80,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Input* o = new Fl_Input(95, 40, 190, 20);
             o->tooltip("The label text for the widget.\nUse Ctrl-J for newlines.");
             o->labelfont(1);
@@ -106,7 +106,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Input* o = new Fl_Input(95, 65, 240, 20);
             o->tooltip("The active image for the widget.");
             o->labelfont(1);
@@ -126,7 +126,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Input* o = new Fl_Input(95, 90, 240, 20);
             o->tooltip("The inactive image for the widget.");
             o->labelfont(1);
@@ -146,14 +146,14 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Button* o = new Fl_Button(95, 115, 45, 20, "Clip");
             o->tooltip("Clip the label to the inside of the widget.");
             o->type(1);
             o->selection_color(FL_INACTIVE_COLOR);
             o->labelsize(11);
             o->callback((Fl_Callback*)align_cb, (void*)(FL_ALIGN_CLIP));
-            o->align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
           } // Fl_Button* o
           { Fl_Button* o = new Fl_Button(145, 115, 50, 20, "Wrap");
             o->tooltip("Wrap the label text.");
@@ -219,7 +219,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { widget_x_input = new Fl_Value_Input(95, 150, 55, 20, "X:");
             widget_x_input->tooltip("The X position of the widget.");
             widget_x_input->labelsize(11);
@@ -227,7 +227,7 @@
             widget_x_input->step(1);
             widget_x_input->textsize(11);
             widget_x_input->callback((Fl_Callback*)x_cb);
-            widget_x_input->align(FL_ALIGN_TOP_LEFT);
+            widget_x_input->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* widget_x_input
           { widget_y_input = new Fl_Value_Input(155, 150, 55, 20, "Y:");
             widget_y_input->tooltip("The Y position of the widget.");
@@ -236,7 +236,7 @@
             widget_y_input->step(1);
             widget_y_input->textsize(11);
             widget_y_input->callback((Fl_Callback*)y_cb);
-            widget_y_input->align(FL_ALIGN_TOP_LEFT);
+            widget_y_input->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* widget_y_input
           { widget_w_input = new Fl_Value_Input(215, 150, 55, 20, "Width:");
             widget_w_input->tooltip("The width of the widget.");
@@ -245,7 +245,7 @@
             widget_w_input->step(1);
             widget_w_input->textsize(11);
             widget_w_input->callback((Fl_Callback*)w_cb);
-            widget_w_input->align(FL_ALIGN_TOP_LEFT);
+            widget_w_input->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* widget_w_input
           { widget_h_input = new Fl_Value_Input(275, 150, 55, 20, "Height:");
             widget_h_input->tooltip("The height of the widget.");
@@ -254,7 +254,7 @@
             widget_h_input->step(1);
             widget_h_input->textsize(11);
             widget_h_input->callback((Fl_Callback*)h_cb);
-            widget_h_input->align(FL_ALIGN_TOP_LEFT);
+            widget_h_input->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* widget_h_input
           { Fl_Light_Button* o = new Fl_Light_Button(335, 150, 55, 20, "Relative");
             o->tooltip("If set, widgets inside a widget class of type Fl_Group are repositioned relat\
@@ -271,21 +271,21 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Value_Input* o = new Fl_Value_Input(95, 185, 55, 20, "Size:");
             o->tooltip("The size of the slider.");
             o->labelsize(11);
             o->step(0.010101);
             o->textsize(11);
             o->callback((Fl_Callback*)slider_size_cb);
-            o->align(FL_ALIGN_TOP_LEFT);
+            o->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* o
           { Fl_Value_Input* o = new Fl_Value_Input(155, 185, 55, 20, "Minimum:");
             o->tooltip("The minimum value of the widget.");
             o->labelsize(11);
             o->textsize(11);
             o->callback((Fl_Callback*)min_cb);
-            o->align(FL_ALIGN_TOP_LEFT);
+            o->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* o
           { Fl_Value_Input* o = new Fl_Value_Input(215, 185, 55, 20, "Maximum:");
             o->tooltip("The maximum value of the widget.");
@@ -293,21 +293,21 @@
             o->value(1);
             o->textsize(11);
             o->callback((Fl_Callback*)max_cb);
-            o->align(FL_ALIGN_TOP_LEFT);
+            o->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* o
           { Fl_Value_Input* o = new Fl_Value_Input(275, 185, 55, 20, "Step:");
             o->tooltip("The resolution of the widget value.");
             o->labelsize(11);
             o->textsize(11);
             o->callback((Fl_Callback*)step_cb);
-            o->align(FL_ALIGN_TOP_LEFT);
+            o->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* o
           { Fl_Value_Input* o = new Fl_Value_Input(335, 185, 55, 20, "Value:");
             o->tooltip("The current widget value.");
             o->labelsize(11);
             o->textsize(11);
             o->callback((Fl_Callback*)value_cb);
-            o->align(FL_ALIGN_TOP_LEFT);
+            o->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* o
           { Fl_Box* o = new Fl_Box(395, 185, 0, 20);
             Fl_Group::current()->resizable(o);
@@ -318,7 +318,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           o->hide();
           { Fl_Value_Input* o = new Fl_Value_Input(95, 185, 55, 20, "Minimum Size:");
             o->tooltip("The size of the slider.");
@@ -327,7 +327,7 @@
             o->step(1);
             o->textsize(11);
             o->callback((Fl_Callback*)min_w_cb);
-            o->align(FL_ALIGN_TOP_LEFT);
+            o->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* o
           { Fl_Value_Input* o = new Fl_Value_Input(155, 185, 55, 20);
             o->tooltip("The minimum value of the widget.");
@@ -336,7 +336,7 @@
             o->step(1);
             o->textsize(11);
             o->callback((Fl_Callback*)min_h_cb);
-            o->align(FL_ALIGN_TOP_LEFT);
+            o->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* o
           { Fl_Button* o = new Fl_Button(215, 185, 25, 20, "set");
             o->labelsize(11);
@@ -349,7 +349,7 @@
             o->step(1);
             o->textsize(11);
             o->callback((Fl_Callback*)max_w_cb);
-            o->align(FL_ALIGN_TOP_LEFT);
+            o->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* o
           { Fl_Value_Input* o = new Fl_Value_Input(305, 185, 55, 20);
             o->tooltip("The resolution of the widget value.");
@@ -358,7 +358,7 @@
             o->step(1);
             o->textsize(11);
             o->callback((Fl_Callback*)max_h_cb);
-            o->align(FL_ALIGN_TOP_LEFT);
+            o->align(Fl_Align(FL_ALIGN_TOP_LEFT));
           } // Fl_Value_Input* o
           { Fl_Button* o = new Fl_Button(365, 185, 25, 20, "set");
             o->labelsize(11);
@@ -379,14 +379,14 @@
           o->labelsize(11);
           o->labelcolor(FL_FOREGROUND_COLOR);
           o->callback((Fl_Callback*)shortcut_in_cb);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           o->when(FL_WHEN_RELEASE);
         } // Shortcut_Button* o
         { Fl_Group* o = new Fl_Group(95, 235, 300, 20, "X Class:");
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Input* o = new Fl_Input(95, 235, 95, 20, ":");
             o->tooltip("The X resource class.");
             o->labelfont(1);
@@ -412,7 +412,7 @@
             o->selection_color((Fl_Color)1);
             o->labelsize(11);
             o->callback((Fl_Callback*)non_modal_cb);
-            o->align(132|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(132|FL_ALIGN_INSIDE));
           } // Fl_Light_Button* o
           o->end();
         } // Fl_Group* o
@@ -420,7 +420,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Light_Button* o = new Fl_Light_Button(95, 260, 60, 20, "Visible");
             o->tooltip("Show the widget.");
             o->selection_color((Fl_Color)1);
@@ -476,7 +476,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Choice* o = new Fl_Choice(95, 40, 170, 20);
             o->tooltip("The style of the label text.");
             o->box(FL_THIN_UP_BOX);
@@ -508,7 +508,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Choice* o = new Fl_Choice(95, 65, 219, 20);
             o->tooltip("The \"up\" box of the widget.");
             o->box(FL_THIN_UP_BOX);
@@ -531,7 +531,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Choice* o = new Fl_Choice(95, 90, 219, 20);
             o->tooltip("The \"down\" box of the widget.");
             o->box(FL_THIN_UP_BOX);
@@ -554,7 +554,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Choice* o = new Fl_Choice(95, 115, 170, 20);
             o->tooltip("The value text style.");
             o->box(FL_DOWN_BOX);
@@ -596,7 +596,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Input* o = new Fl_Input(95, 40, 172, 20);
             o->tooltip("The widget subclass.");
             o->labelfont(1);
@@ -620,7 +620,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Input* o = new Fl_Input(95, 65, 235, 20);
             o->tooltip("The name of the widget.");
             o->labelfont(1);
@@ -691,7 +691,7 @@
           o->textfont(4);
           o->textsize(11);
           o->callback((Fl_Callback*)callback_cb);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           o->when(FL_WHEN_RELEASE);
           Fl_Group::current()->resizable(o);
         } // CodeEditor* o
@@ -699,7 +699,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Input* o = new Fl_Input(95, 270, 158, 20);
             o->tooltip("The user data to pass into the callback code.");
             o->labelfont(1);
@@ -726,7 +726,7 @@
           o->labelfont(1);
           o->labelsize(11);
           o->callback((Fl_Callback*)propagate_load);
-          o->align(FL_ALIGN_LEFT);
+          o->align(Fl_Align(FL_ALIGN_LEFT));
           { Fl_Input* o = new Fl_Input(95, 295, 158, 20);
             o->tooltip("The type of the user data.");
             o->labelfont(1);
@@ -785,6 +785,7 @@
       o->end();
     } // Fl_Group* o
     o->size_range(o->w(), o->h());
+    o->xtype(FL_DIALOG_WINDOW);
     o->end();
   } // Fl_Double_Window* o
   return w;
Index: fluid/function_panel.cxx
===================================================================
--- fluid/function_panel.cxx	(revision 6985)
+++ fluid/function_panel.cxx	(working copy)
@@ -69,7 +69,7 @@
 Fl_Text_Editor *f_comment_input=(Fl_Text_Editor *)0;
 
 Fl_Double_Window* make_function_panel() {
-  { function_panel = new Fl_Double_Window(343, 232, "Function/Method Properties");
+  { Fl_Double_Window* o = function_panel = new Fl_Double_Window(340, 230, "Function/Method Properties");
     { Fl_Group* o = new Fl_Group(10, 10, 270, 20);
       { f_public_member_choice = new Fl_Choice(10, 10, 75, 20);
         f_public_member_choice->tooltip("Change member access attribute.");
@@ -141,6 +141,7 @@
       Fl_Group::current()->resizable(f_comment_input);
       f_comment_input->buffer(new Fl_Text_Buffer());
     } // Fl_Text_Editor* f_comment_input
+    o->xtype(FL_DIALOG_WINDOW);
     function_panel->set_modal();
     function_panel->end();
   } // Fl_Double_Window* function_panel
@@ -190,6 +191,7 @@
       o->end();
     } // Fl_Group* o
     o->size_range(200, 150);
+    o->xtype(FL_DIALOG_WINDOW);
     code_panel->set_modal();
     code_panel->end();
   } // Fl_Double_Window* code_panel
@@ -241,6 +243,7 @@
       o->end();
     } // Fl_Group* o
     o->size_range(o->w(), o->h(), Fl::w(), o->h());
+    o->xtype(FL_DIALOG_WINDOW);
     codeblock_panel->set_modal();
     codeblock_panel->end();
   } // Fl_Double_Window* codeblock_panel
@@ -322,6 +325,7 @@
       o->end();
     } // Fl_Group* o
     o->size_range(o->w(), o->h(), Fl::w(), o->h());
+    o->xtype(FL_DIALOG_WINDOW);
     declblock_panel->set_modal();
     declblock_panel->end();
   } // Fl_Double_Window* declblock_panel
@@ -358,7 +362,7 @@
 Fl_Text_Editor *decl_comment_input=(Fl_Text_Editor *)0;
 
 Fl_Double_Window* make_decl_panel() {
-  { decl_panel = new Fl_Double_Window(343, 237, "Declaration Properties");
+  { Fl_Double_Window* o = decl_panel = new Fl_Double_Window(340, 235, "Declaration Properties");
     decl_panel->align(Fl_Align(FL_ALIGN_CLIP|FL_ALIGN_INSIDE));
     { Fl_Group* o = new Fl_Group(10, 10, 270, 20);
       { Fl_Box* o = new Fl_Box(200, 10, 80, 20);
@@ -414,6 +418,7 @@
       Fl_Group::current()->resizable(decl_comment_input);
       decl_comment_input->buffer(new Fl_Text_Buffer());
     } // Fl_Text_Editor* decl_comment_input
+    o->xtype(FL_DIALOG_WINDOW);
     decl_panel->size_range(343, 237);
     decl_panel->end();
   } // Fl_Double_Window* decl_panel
@@ -435,7 +440,7 @@
 Fl_Button *c_panel_cancel=(Fl_Button *)0;
 
 Fl_Double_Window* make_class_panel() {
-  { class_panel = new Fl_Double_Window(342, 196, "Class Properties");
+  { Fl_Double_Window* o = class_panel = new Fl_Double_Window(340, 195, "Class Properties");
     class_panel->labelsize(11);
     { Fl_Group* o = new Fl_Group(10, 10, 280, 20);
       o->hide();
@@ -493,6 +498,7 @@
       } // Fl_Box* o
       o->end();
     } // Fl_Group* o
+    o->xtype(FL_DIALOG_WINDOW);
     class_panel->set_modal();
     class_panel->size_range(343, 188);
     class_panel->end();
@@ -576,6 +582,7 @@
       o->end();
     } // Fl_Group* o
     o->size_range(320, 180);
+    o->xtype(FL_DIALOG_WINDOW);
     comment_panel->set_modal();
     comment_panel->end();
   } // Fl_Double_Window* comment_panel
@@ -605,7 +612,7 @@
 }
 
 Fl_Window* make_widgetbin() {
-  { widgetbin_panel = new Fl_Window(550, 85, "Widget Bin");
+  { Fl_Window* o = widgetbin_panel = new Fl_Window(550, 85, "Widget Bin");
     widgetbin_panel->callback((Fl_Callback*)cb_widgetbin_panel);
     widgetbin_panel->align(Fl_Align(FL_ALIGN_CLIP|FL_ALIGN_INSIDE));
     { Fl_Group* o = new Fl_Group(3, 3, 79, 79);
@@ -926,6 +933,7 @@
       } // Fl_Button* o
       o->end();
     } // Fl_Group* o
+    o->xtype(FL_DIALOG_WINDOW);
     widgetbin_panel->set_non_modal();
     widgetbin_panel->end();
   } // Fl_Window* widgetbin_panel
Index: fluid/template_panel.fl
===================================================================
--- fluid/template_panel.fl	(revision 6985)
+++ fluid/template_panel.fl	(working copy)
@@ -66,8 +66,9 @@
 template_browser->deselect();
 template_name->value("");
 template_instance->value("");
-template_panel->hide();} open
-    xywh {340 237 460 355} type Double resizable modal visible
+template_panel->hide();} open selected
+    xywh {53 186 460 355} type Double resizable
+    code0 {o->xtype(FL_DIALOG_WINDOW);} modal visible
   } {
     Fl_Browser template_browser {
       label {Available Templates:}
@@ -181,7 +182,7 @@
 template_browser->clear();} {}
 } 
 
-Function {template_delete_cb(Fl_Button *, void *)} {selected return_type void
+Function {template_delete_cb(Fl_Button *, void *)} {return_type void
 } {
   code {int item = template_browser->value();
 if (item < 1) return;
Index: fluid/widget_panel.fl
===================================================================
--- fluid/widget_panel.fl	(revision 6985)
+++ fluid/widget_panel.fl	(working copy)
@@ -1,5 +1,5 @@
 # data file for the Fltk User Interface Designer (fluid)
-version 1.0108 
+version 1.0300 
 header_name {.h} 
 code_name {.cxx}
 comment {//
@@ -33,9 +33,10 @@
 
 Function {make_widget_panel()} {open
 } {
-  Fl_Window {} {open
-    xywh {383 206 420 360} type Double labelsize 11 align 80 resizable hotspot
-    code0 {o->size_range(o->w(), o->h());} visible
+  Fl_Window {} {open selected
+    xywh {149 173 420 360} type Double labelsize 11 align 80 resizable hotspot
+    code0 {o->size_range(o->w(), o->h());}
+    code1 {o->xtype(FL_DIALOG_WINDOW);} visible
   } {
     Fl_Tabs {} {
       callback {propagate_load((Fl_Group *)o,v);} open
@@ -438,7 +439,7 @@
           xywh {95 65 310 20} labelfont 1 labelsize 11 align 4
         } {
           Fl_Input {} {
-            callback name_cb selected
+            callback name_cb
             tooltip {The name of the widget.} xywh {95 65 235 20} labelfont 1 labelsize 11 textsize 11 resizable
           }
           Fl_Choice {} {
Index: fluid/function_panel.fl
===================================================================
--- fluid/function_panel.fl	(revision 6985)
+++ fluid/function_panel.fl	(working copy)
@@ -51,8 +51,9 @@
 
 Function {make_function_panel()} {} {
   Fl_Window function_panel {
-    label {Function/Method Properties} open
-    xywh {394 671 343 232} type Double resizable modal visible
+    label {Function/Method Properties} open selected
+    xywh {256 294 340 230} type Double resizable
+    code0 {o->xtype(FL_DIALOG_WINDOW);} modal visible
   } {
     Fl_Group {} {open
       xywh {10 10 270 20}
@@ -132,8 +133,9 @@
 Function {make_code_panel()} {} {
   Fl_Window code_panel {
     label {Code Properties}
-    xywh {353 262 540 180} type Double labelsize 11 resizable
-    code0 {o->size_range(200, 150);} modal visible
+    xywh {228 354 540 180} type Double labelsize 11 resizable
+    code0 {o->size_range(200, 150);}
+    code1 {o->xtype(FL_DIALOG_WINDOW);} modal visible
   } {
     Fl_Text_Editor code_input {
       xywh {10 10 520 130} box DOWN_BOX labelsize 11 textfont 4 textsize 11 resizable
@@ -162,8 +164,9 @@
 Function {make_codeblock_panel()} {} {
   Fl_Window codeblock_panel {
     label {Code Block Properties}
-    xywh {468 221 300 115} type Double labelsize 11 resizable
-    code0 {o->size_range(o->w(), o->h(), Fl::w(), o->h());} modal visible
+    xywh {261 412 300 115} type Double labelsize 11 resizable
+    code0 {o->size_range(o->w(), o->h(), Fl::w(), o->h());}
+    code1 {o->xtype(FL_DIALOG_WINDOW);} modal visible
   } {
     Fl_Input code_before_input {
       label {Conditional code block}
@@ -191,11 +194,13 @@
   }
 } 
 
-Function {make_declblock_panel()} {} {
+Function {make_declblock_panel()} {open
+} {
   Fl_Window declblock_panel {
     label {Declaration Block Properties} open
-    xywh {428 215 300 135} type Double labelsize 11 resizable
-    code0 {o->size_range(o->w(), o->h(), Fl::w(), o->h());} modal visible
+    xywh {174 438 300 135} type Double labelsize 11 resizable
+    code0 {o->size_range(o->w(), o->h(), Fl::w(), o->h());}
+    code1 {o->xtype(FL_DIALOG_WINDOW);} modal visible
   } {
     Fl_Group {} {open
       xywh {10 10 280 20}
@@ -229,7 +234,7 @@
       label {"\\n...child code...\\n" is inserted here}
       tooltip {\#endif or similar declaration code block.} xywh {10 75 280 20} labelsize 11 align 5 when 0 textfont 4 textsize 11
     }
-    Fl_Group {} {
+    Fl_Group {} {open
       xywh {10 105 280 20}
     } {
       Fl_Return_Button declblock_panel_ok {
@@ -250,7 +255,8 @@
 Function {make_decl_panel()} {} {
   Fl_Window decl_panel {
     label {Declaration Properties} open
-    xywh {395 411 343 237} type Double align 80 resizable size_range {343 237 0 0} visible
+    xywh {312 170 340 235} type Double align 80 resizable
+    code0 {o->xtype(FL_DIALOG_WINDOW);} size_range {343 237 0 0} visible
   } {
     Fl_Group {} {open
       xywh {10 10 270 20}
@@ -322,10 +328,12 @@
   }
 } 
 
-Function {make_class_panel()} {} {
+Function {make_class_panel()} {open
+} {
   Fl_Window class_panel {
     label {Class Properties} open
-    xywh {395 191 342 196} type Double labelsize 11 resizable modal size_range {343 188 0 0} visible
+    xywh {220 450 340 195} type Double labelsize 11 resizable
+    code0 {o->xtype(FL_DIALOG_WINDOW);} modal size_range {343 188 0 0} visible
   } {
     Fl_Group {} {open
       xywh {10 10 280 20} hide
@@ -369,11 +377,13 @@
   }
 } 
 
-Function {make_comment_panel()} {} {
+Function {make_comment_panel()} {open
+} {
   Fl_Window comment_panel {
     label {Comment Properties} open
-    xywh {422 190 550 280} type Double labelsize 11 resizable
-    code0 {o->size_range(320, 180);} modal visible
+    xywh {98 355 550 280} type Double labelsize 11 resizable
+    code0 {o->size_range(320, 180);}
+    code1 {o->xtype(FL_DIALOG_WINDOW);} modal visible
   } {
     Fl_Text_Editor comment_input {
       xywh {110 10 430 230} box DOWN_BOX labelsize 11 textfont 4 textsize 11 resizable
@@ -441,8 +451,9 @@
     callback {if (Fl::event()==FL_SHORTCUT && Fl::event_key()==FL_Escape)
   exit_cb((Fl_Widget*)o, v);
 else  
-  toggle_widgetbin_cb((Fl_Widget*)o, v);} open selected
-    xywh {410 171 550 85} type Single align 80 non_modal visible
+  toggle_widgetbin_cb((Fl_Widget*)o, v);} open
+    xywh {195 402 550 85} type Single align 80
+    code0 {o->xtype(FL_DIALOG_WINDOW);} non_modal visible
   } {
     Fl_Group {} {
       xywh {3 3 79 79}
@@ -773,11 +784,12 @@
   }
 } 
 
-Function {make_sourceview()} {} {
+Function {make_sourceview()} {open
+} {
   Fl_Window sourceview_panel {
     label {Code View}
-    callback toggle_sourceview_cb
-    xywh {430 273 520 490} type Double align 80 resizable size_range {384 120 0 0} visible
+    callback toggle_sourceview_cb open
+    xywh {76 252 520 490} type Double align 80 resizable size_range {384 120 0 0} visible
   } {
     Fl_Tabs sv_tab {
       callback update_sourceview_position_cb
@@ -804,7 +816,7 @@
         }
       }
     }
-    Fl_Group {} {
+    Fl_Group {} {open
       xywh {10 460 500 20}
     } {
       Fl_Button {} {
Index: fluid/print_panel.fl
===================================================================
--- fluid/print_panel.fl	(revision 6985)
+++ fluid/print_panel.fl	(working copy)
@@ -1,5 +1,5 @@
 # data file for the Fltk User Interface Designer (fluid)
-version 1.0107 
+version 1.0300 
 header_name {.h} 
 code_name {.cxx}
 comment {//
@@ -44,8 +44,9 @@
 Function {make_print_panel()} {open
 } {
   Fl_Window print_panel {
-    label Print open
-    xywh {342 21 465 235} type Double modal visible
+    label Print open selected
+    xywh {342 25 465 235} type Double
+    code0 {o->xtype(FL_DIALOG_WINDOW);} modal visible
   } {
     Fl_Group print_panel_controls {open
       xywh {10 10 447 216}
@@ -109,7 +110,7 @@
   print_collate_button->activate();
   print_collate_group[0]->activate();
   print_collate_group[1]->activate();
-}} selected
+}}
           xywh {321 96 45 25} when 1
         }
         Fl_Check_Button print_collate_button {
@@ -219,7 +220,8 @@
     label {Printer Properties}
     callback {print_properties_panel->hide();
 print_update_status();} open
-    xywh {340 213 290 130} type Double modal visible
+    xywh {340 213 290 130} type Double
+    code0 {o->xtype(FL_DIALOG_WINDOW);} modal visible
   } {
     Fl_Choice print_page_size {
       label {Page Size:}
Index: fluid/print_panel.cxx
===================================================================
--- fluid/print_panel.cxx	(revision 6985)
+++ fluid/print_panel.cxx	(working copy)
@@ -244,7 +244,7 @@
 }
 
 Fl_Double_Window* make_print_panel() {
-  { print_panel = new Fl_Double_Window(465, 235, "Print");
+  { Fl_Double_Window* o = print_panel = new Fl_Double_Window(465, 235, "Print");
     { print_panel_controls = new Fl_Group(10, 10, 447, 216);
       { print_choice = new Fl_Choice(113, 10, 181, 25, "Printer:");
         print_choice->down_box(FL_BORDER_BOX);
@@ -256,12 +256,12 @@
         print_properties->callback((Fl_Callback*)cb_print_properties);
       } // Fl_Button* print_properties
       { print_status = new Fl_Box(111, 41, 288, 17, "printer/job status");
-        print_status->align(68|FL_ALIGN_INSIDE);
+        print_status->align(Fl_Align(68|FL_ALIGN_INSIDE));
       } // Fl_Box* print_status
       { Fl_Group* o = new Fl_Group(10, 86, 227, 105, "Print Range");
         o->box(FL_THIN_DOWN_BOX);
         o->labelfont(1);
-        o->align(FL_ALIGN_TOP_LEFT);
+        o->align(Fl_Align(FL_ALIGN_TOP_LEFT));
         { print_all = new Fl_Round_Button(20, 96, 38, 25, "All");
           print_all->type(102);
           print_all->down_box(FL_ROUND_DOWN_BOX);
@@ -293,9 +293,8 @@
       { Fl_Group* o = new Fl_Group(247, 86, 210, 105, "Copies");
         o->box(FL_THIN_DOWN_BOX);
         o->labelfont(1);
-        o->align(FL_ALIGN_TOP_LEFT);
+        o->align(Fl_Align(FL_ALIGN_TOP_LEFT));
         { print_copies = new Fl_Spinner(321, 96, 45, 25, "# Copies:");
-          print_copies->value(1);
           print_copies->callback((Fl_Callback*)cb_print_copies);
           print_copies->when(FL_WHEN_CHANGED);
         } // Fl_Spinner* print_copies
@@ -311,63 +310,63 @@
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
             o->deactivate();
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(272, 136, 30, 40, "1");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
             o->deactivate();
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(257, 131, 30, 40, "1");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
             o->deactivate();
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(352, 141, 30, 40, "2");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
             o->deactivate();
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(337, 136, 30, 40, "2");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
             o->deactivate();
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(322, 131, 30, 40, "2");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
             o->deactivate();
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(417, 141, 30, 40, "3");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
             o->deactivate();
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(402, 136, 30, 40, "3");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
             o->deactivate();
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(387, 131, 30, 40, "3");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
             o->deactivate();
           } // Fl_Box* o
           print_collate_group[0]->end();
@@ -379,55 +378,55 @@
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(272, 136, 30, 40, "2");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(257, 131, 30, 40, "1");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(352, 141, 30, 40, "3");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(337, 136, 30, 40, "2");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(322, 131, 30, 40, "1");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(417, 141, 30, 40, "3");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(402, 136, 30, 40, "2");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
           } // Fl_Box* o
           { Fl_Box* o = new Fl_Box(387, 131, 30, 40, "1");
             o->box(FL_BORDER_BOX);
             o->color(FL_BACKGROUND2_COLOR);
             o->labelsize(11);
-            o->align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE);
+            o->align(Fl_Align(FL_ALIGN_BOTTOM_RIGHT|FL_ALIGN_INSIDE));
           } // Fl_Box* o
           print_collate_group[1]->end();
         } // Fl_Group* print_collate_group[1]
@@ -445,10 +444,11 @@
       print_progress->selection_color((Fl_Color)4);
       print_progress->hide();
     } // Fl_Progress* print_progress
+    o->xtype(FL_DIALOG_WINDOW);
     print_panel->set_modal();
     print_panel->end();
   } // Fl_Double_Window* print_panel
-  { print_properties_panel = new Fl_Double_Window(290, 130, "Printer Properties");
+  { Fl_Double_Window* o = print_properties_panel = new Fl_Double_Window(290, 130, "Printer Properties");
     print_properties_panel->callback((Fl_Callback*)cb_print_properties_panel);
     { print_page_size = new Fl_Choice(110, 10, 80, 25, "Page Size:");
       print_page_size->down_box(FL_BORDER_BOX);
@@ -457,7 +457,7 @@
     } // Fl_Choice* print_page_size
     { Fl_Group* o = new Fl_Group(110, 45, 170, 40, "Output Mode:");
       o->labelfont(1);
-      o->align(FL_ALIGN_LEFT);
+      o->align(Fl_Align(FL_ALIGN_LEFT));
       { print_output_mode[0] = new Fl_Button(110, 45, 30, 40);
         print_output_mode[0]->type(102);
         print_output_mode[0]->box(FL_BORDER_BOX);
@@ -502,6 +502,7 @@
     { Fl_Button* o = new Fl_Button(60, 95, 53, 25, "Use");
       o->callback((Fl_Callback*)cb_Use);
     } // Fl_Button* o
+    o->xtype(FL_DIALOG_WINDOW);
     print_properties_panel->set_modal();
     print_properties_panel->end();
   } // Fl_Double_Window* print_properties_panel
